pycocoa.colors.TintColor

Package pycocoa :: Module colors :: Class TintColor |
[frames] | no frames]

# Class TintColor

      object --+
               |
    bases._Type0 --+
                   |
               Color --+
                       |
            _SystemColor --+
                           |
                          TintColor

Dynamic color, adaptable to vibrancy and accessibility settings.

Instance Methods
__init__(self, name) New Color from an existing `NSColor`. |
Inherited from `Color`: `copy`, `toCMY3`, `toHSB3`, `toRGB3` Inherited from `bases._Type0`: `__repr__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_SystemColor`: `n` Inherited from `Color`: `alpha`, `black`, `blue`, `brightness`, `colorSpace`, `cyan`, `green`, `hex`, `hue`, `magenta`, `name`, `nsColor`, `red`, `saturation`, `white`, `yellow` Inherited from `bases._Type0`: `NS`, `NSDelegate` Inherited from `object`: `__class__`

Method Details

### __init__(self, name) (Constructor) |
New Color from an existing `NSColor`. Parameters: `name` - Given color nsme (`str`). `nsColor` - Optionally, the name of an existing `NSColor` (`str`). Raises: `ColorError` - Invalid `name` or `nsColor`. Overrides: object.__init__ (inherited documentation)